/**
 * neopixel - An Arduino sketch that exercises the WS2812b LEDs
 * 
 * Hardware setup
 * ==============
 * The din connector on the LED strip should be connected to pin 6 on the Arduino
 * 
 * Author: Mario Gianota August 2020
 */
#include "FastLED.h"

#define NUM_LEDS 30 // Change this number if you to match the number of LEDs you have

CRGB leds[NUM_LEDS];


void setup() { 
  FastLED.addLeds<NEOPIXEL, 6>(leds, NUM_LEDS); 
}

void loop() {
  pattern1(10);
  pattern2(10);
  progress(1);
  binaryCount(256);
  progress(1);
  pattern5(130);
  progress(1);
  pattern4(40);
  progress(1);
  pattern3(50);
}

void pattern1(int numCycles) {
    int cycles = 1;
    for(int i=0; i< NUM_LEDS; i++) {
      leds[i].r = 0;
      leds[i].g = 0;
      leds[i].b = 10;
    }
    while( cycles <= numCycles ) {
      for(int dot = 0; dot < NUM_LEDS; dot++) { 
        leds[dot] = CRGB::White;
        if( dot > 0 )
          leds[dot-1] = 10;
        FastLED.show();
        // clear this led for the next time around the loop
        leds[dot] = CRGB::Black;
        delay(30);
  
      }
      cycles++;
    } 
}

void pattern2(int numCycles) {
  int cycles = 1;
  while( cycles <= numCycles ) {
  for(int dot = 0; dot < NUM_LEDS; dot++) {
      leds[dot] = CRGB::Red;
      if( dot > 0 )
        leds[dot - 1] = CRGB::White;
      FastLED.show();
      // clear this led for the next time around the loop
      leds[dot] = CRGB::Black;
      delay(30);

  }
  for(int dot = NUM_LEDS-1; dot >=1; dot--) {
      leds[dot] = CRGB::Red;
      FastLED.show();
      // clear this led for the next time around the loop
      leds[dot] = CRGB::Black;
      delay(30);

  }
  cycles++;
  }
}

void pattern3(int numCycles) {
  int cycles = 1;
  int d = 100;
  uint8_t r = random(0, 255);
  uint8_t g = random(0, 255);
  uint8_t b = random(0, 255);
  int counter = 0;
  while( cycles <= numCycles ) {
    if( counter++ % 4 == 0 ) {
      r = random(0,255);
      g = random(0, 255);
      b = random(0, 255);
    }
    
    for(int i=0; i<NUM_LEDS; i++) {
      //leds[i] = CRGB::Red;
      leds[i].r = r;
      leds[i].g = g;
      leds[i].b = b;
    }
    FastLED.show();
    delay(d);
    allOff(d);
    cycles++;
  }
}
void allOff(int d) {
    for(int i=0; i<NUM_LEDS; i++) {
      leds[i] = CRGB::Black;
    }
    FastLED.show();
    delay(d);
}

void pattern4(int numCycles) {
  int cycles = 1;
  for(int i=0; i<NUM_LEDS; i+=2) {
    leds[i] = CRGB::Green;
  }
  while( cycles <= numCycles) {
    for(int dot = 1; dot < NUM_LEDS; dot+=2) { 
      leds[dot] = CRGB::White;
      FastLED.show();
      // clear this led for the next time around the loop
      leds[dot] = CRGB::Black;
      delay(30);
    }
    cycles++;
  }
}

void progress(int numCycles) {
  int cycles = 1;
  while( cycles <= numCycles)  {
    for(int i=0; i<NUM_LEDS; i++) {
      leds[i] = CRGB::Blue;
      FastLED.show();
      delay(30);
    }
    allOff(1);
    cycles++;
  }
}

void pattern5(int numCycles) {
  int cycles = 1;
  while( cycles <= numCycles) {
    for(int i=0; i<NUM_LEDS; i+=2) {
      leds[i] = CRGB::Green;
    }
    int rnd = (int)random(0,NUM_LEDS-1);
    if( rnd % 2 != 1 )
      rnd++;
    leds[rnd] = CRGB::White;  
    FastLED.show();
    delay(100);
    leds[rnd] = CRGB::Black;
    cycles++;
  }
}

void binaryCount(int numCycles) {
  int cycles = 1;
  uint8_t counter = 0;
  while( cycles <= numCycles)  {
    leds[18] = counter & 1 ? CRGB::Red : CRGB::Blue;
    leds[17] = counter & 2 ? CRGB::Red : CRGB::Blue;
    leds[16] = counter & 4 ? CRGB::Red : CRGB::Blue;
    leds[15] = counter & 8 ? CRGB::Red : CRGB::Blue;
    leds[14] = counter & 16 ? CRGB::Red : CRGB::Blue;
    leds[13] = counter & 32 ? CRGB::Red : CRGB::Blue;
    leds[12] = counter & 64 ? CRGB::Red : CRGB::Blue;
    leds[11] = counter & 128 ? CRGB::Red : CRGB::Blue;
    FastLED.show();
    delay(180);
    cycles++;
    counter++;
  }
  delay(2000);
  //FastLED.clear();
}
